@@ -1,4 +1,9 @@
 """Definition of the supported bulb effects."""
+
+from typing import Dict, Iterable, List, cast
+
+from pywizlight.bulblibrary import BulbClass
+
 SCENES = {
     1: "Ocean",
     2: "Romance",
@@ -35,6 +40,14 @@ SCENES = {
     1000: "Rhythm",
 }
 SCENE_NAME_TO_ID = {scene_name: scene_id for (scene_id, scene_name) in SCENES.items()}
+TW_SCENES = [6, 9, 10, 11, 12, 13, 14, 15, 16, 18, 29, 30, 31, 32]
+DW_SCENES = [9, 10, 13, 14, 29, 30, 31, 32]
+
+SCENES_BY_CLASS: Dict[BulbClass, List[str]] = {
+    BulbClass.RGB: list(cast(Iterable, SCENES.values())),
+    BulbClass.TW: [SCENES[key] for key in TW_SCENES],
+    BulbClass.DW: [SCENES[key] for key in DW_SCENES],
+}
 
 
 def get_id_from_scene_name(scene: str) -> int:
