@@ -117,6 +117,34 @@ MODULE_CONFIGS = {  # AKA getModelConfig
 }
 
 SYSTEM_CONFIGS = {  # AKA getSystemConfig
+    ("1.8.0-MISSING-TYPEID-0", "1.8.0"): {
+        "method": "getSystemConfig",
+        "env": "pro",
+        "result": {
+            "mac": "a8bb502054e3",
+            "homeId": 5385975,
+            "homeLock": False,
+            "pairingLock": False,
+            "typeId": 0,
+            "fwVersion": "1.8.0",
+            "groupId": 0,
+            "drvConf": [20, 1],
+        },
+    },
+    ("1.8.0-MISSING-TYPEID-1", "1.8.0"): {
+        "method": "getSystemConfig",
+        "env": "pro",
+        "result": {
+            "mac": "a8bb502054e3",
+            "homeId": 5385975,
+            "homeLock": False,
+            "pairingLock": False,
+            "typeId": 1,
+            "fwVersion": "1.8.0",
+            "groupId": 0,
+            "drvConf": [20, 1],
+        },
+    },
     ("ESP01_SHRGB_03", "1.25.0"): {
         "method": "getSystemConfig",
         "env": "pro",
@@ -300,6 +328,53 @@ SYSTEM_CONFIGS = {  # AKA getSystemConfig
             "drvConf": [20, 2],
         },
     },
+    ("ESP14_SHTW1C_01", "1.18.0"): {
+        "method": "getSystemConfig",
+        "env": "pro",
+        "result": {
+            "mac": "a8bb503ea5f4",
+            "homeId": 5385975,
+            "roomId": 0,
+            "homeLock": False,
+            "pairingLock": False,
+            "typeId": 0,
+            "moduleName": "ESP14_SHTW1C_01",
+            "fwVersion": "1.18.0",
+            "groupId": 0,
+            "drvConf": [20, 1],
+        },
+    },
+    ("ESP06_SHDW9_01", "1.11.7"): {
+        "method": "getSystemConfig",
+        "env": "",
+        "result": {
+            "mac": "a8bb509f71d1",
+            "homeId": 0,
+            "homeLock": False,
+            "pairingLock": False,
+            "typeId": 0,
+            "moduleName": "ESP06_SHDW9_01",
+            "fwVersion": "1.11.7",
+            "groupId": 0,
+            "drvConf": [20, 1],
+        },
+    },
+    ("ESP20_DHRGB_01B", "1.21.40"): {
+        "method": "getSystemConfig",
+        "env": "pro",
+        "result": {
+            "mac": "d8a01199cf31",
+            "homeId": 5385975,
+            "roomId": 8201410,
+            "moduleName": "ESP20_DHRGB_01B",
+            "fwVersion": "1.21.40",
+            "groupId": 0,
+            "drvConf": [20, 2],
+            "ewf": [200, 255, 150, 255, 0, 0, 40],
+            "ewfHex": "c8ff96ff000028",
+            "ping": 0,
+        },
+    },
 }
 
 USER_CONFIGS = {  # AKA getUserConfig
@@ -360,6 +435,72 @@ USER_CONFIGS = {  # AKA getUserConfig
             "po": False,
         },
     },
+    ("ESP14_SHTW1C_01", "1.18.0"): {
+        "method": "getUserConfig",
+        "env": "pro",
+        "result": {
+            "fadeIn": 450,
+            "fadeOut": 500,
+            "fadeNight": False,
+            "dftDim": 100,
+            "pwmRange": [0, 100],
+            "whiteRange": [2700, 6500],
+            "extRange": [2700, 6500],
+            "opMode": 0,
+            "po": False,
+        },
+    },
+    ("ESP06_SHDW9_01", "1.11.7"): {
+        "method": "getUserConfig",
+        "env": "pro",
+        "result": {
+            "fadeIn": 450,
+            "fadeOut": 500,
+            "fadeNight": False,
+            "dftDim": 100,
+            "pwmRange": [0, 100],
+            "whiteRange": [2700, 6500],
+            "extRange": [2700, 6500],
+        },
+    },
+    ("ESP20_DHRGB_01B", "1.21.40"): {
+        "method": "getUserConfig",
+        "env": "pro",
+        "result": {
+            "fadeIn": 500,
+            "fadeOut": 500,
+            "dftDim": 100,
+            "pwmRange": [0, 100],
+            "whiteRange": [2700, 6500],
+            "extRange": [2200, 6500],
+            "opMode": 0,
+            "po": True,
+        },
+    },
+    ("1.8.0-MISSING-TYPEID-0", "1.8.0"): {
+        "method": "getUserConfig",
+        "env": "pro",
+        "result": {
+            "fadeIn": 500,
+            "fadeOut": 500,
+            "fadeNight": False,
+            "dftDim": 100,
+            "pwmRange": [5, 100],
+            "whiteRange": [2700, 2700],
+        },
+    },
+    ("1.8.0-MISSING-TYPEID-1", "1.8.0"): {
+        "method": "getUserConfig",
+        "env": "pro",
+        "result": {
+            "fadeIn": 500,
+            "fadeOut": 500,
+            "fadeNight": False,
+            "dftDim": 100,
+            "pwmRange": [5, 100],
+            "whiteRange": [2700, 2700],
+        },
+    },
 }
 
 
